'use strict'

const flatten = require('lodash.flatten')

exports.topics = [
  { name: 'apps', description: 'manage apps' },
  { name: 'buildpacks', description: 'manage the buildpacks for an app' },
  { name: 'config', description: 'manage app config vars' },
  { name: 'domains', description: 'manage the domains for an app' },
  { name: 'drains', description: 'list all log drains' },
  { name: 'dyno', hidden: true },
  { name: 'features', description: 'manage optional features' },
  { name: 'keys', description: 'manage ssh keys' },
  { name: 'labs', description: 'experimental features' },
  { name: 'maintenance', description: 'manage maintenance mode for an app' },
  { name: 'notifications', description: 'display notifications' },
  { name: 'ps', description: 'manage dynos (dynos, workers)' },
  { name: 'regions', description: 'list available regions' },
  { name: 'releases', description: 'manage app releases' }
]

exports.commands = flatten([
  require('./commands/apps'),
  require('./commands/apps/create'),
  require('./commands/apps/destroy'),
  require('./commands/apps/errors'),
  require('./commands/apps/favorites'),
  require('./commands/apps/favorites/add'),
  require('./commands/apps/favorites/remove'),
  require('./commands/apps/info'),
  require('./commands/apps/open'),
  require('./commands/apps/rename'),
  require('./commands/apps/stacks'),
  require('./commands/apps/stacks/set'),
  require('./commands/auth/2fa'),
  require('./commands/auth/2fa/disable'),
  require('./commands/auth/2fa/generate'),
  require('./commands/auth/login'),
  require('./commands/auth/logout'),
  require('./commands/auth/token'),
  require('./commands/auth/whoami'),
  require('./commands/buildpacks'),
  require('./commands/buildpacks/add.js'),
  require('./commands/buildpacks/clear.js'),
  require('./commands/buildpacks/remove.js'),
  require('./commands/buildpacks/set.js'),
  require('./commands/config'),
  require('./commands/config/get'),
  require('./commands/config/set'),
  require('./commands/config/unset'),
  require('./commands/dashboard'),
  require('./commands/domains'),
  require('./commands/domains/add'),
  require('./commands/domains/clear'),
  require('./commands/domains/remove'),
  require('./commands/domains/wait'),
  require('./commands/drains'),
  require('./commands/drains/add'),
  require('./commands/drains/remove'),
  require('./commands/features'),
  require('./commands/features/disable'),
  require('./commands/features/enable'),
  require('./commands/features/info'),
  require('./commands/keys'),
  require('./commands/keys/add'),
  require('./commands/keys/clear'),
  require('./commands/keys/remove'),
  require('./commands/labs'),
  require('./commands/labs/disable'),
  require('./commands/labs/enable'),
  require('./commands/labs/info'),
  require('./commands/maintenance'),
  require('./commands/maintenance/off'),
  require('./commands/maintenance/on'),
  require('./commands/notifications'),
  require('./commands/ps'),
  require('./commands/ps/restart'),
  require('./commands/ps/scale'),
  require('./commands/ps/stop'),
  require('./commands/ps/type'),
  require('./commands/regions'),
  require('./commands/releases'),
  require('./commands/releases/info'),
  require('./commands/releases/rollback'),
  require('./commands/releases/output')
])
